<?php defined('SYSPATH') OR die('No direct access allowed.');
/*
 * Arlicle admin Diagram Manage controller.
 * 
 * @packpage	Arlicle
 * @author 		Edison Rao
 * @copyright 	(c) 2009 Arlicle Team
 * @license 	GNU General Public License 2.0 
 */

class Diagram_Manage_Controller extends Controller {

    public function __construct() {
        parent::__construct();
        // check role
        if (Router::$method != 'index' && !$this->user->can('manage_diagram')) {
            die(T::_('You are not access allowed.'));
        }
    }

    public function index() {
        $view = new View('layouts/admin');
        $view->page_title = 'Diagram Manage';
        $view->diagram_list = Diagram::draw_diagram('manage');
        $view->render(TRUE);
    }

	/**
	 * add a new diagram, add a child diagram by parent id, add diagram by a mate id, edit a diagram, 
	 *
	 * @param  integer
	 * @param  string
	 * a. $id=null and $action=null, add a new diagram
	 * b. $id!=null and $action='add_done', $id is diagram last insert id
	 * c. $id!=null and $action='add_a_child', $id is a diagram parent id
	 */
    public function diagram_new($id = null, $action = null) {
        $parent_id = 0; // current add parent id
        if ($action == 'add_a_child') {
            $parent_id = $id;
            $id = null;
        } else if ($action == 'add_done') {
            $parent_id = ORM::factory('diagram')->where('id', $id)->find()->parent_id;
            $id = null;
        }
        $diagram = new Diagram_Model($id);
        $list = $diagram->customfields;
        // add new or save edit
        if ($post = $this->input->post()) {
            // get the diagram id, if is not edit action ,unset the $id
            $type = $this->input->post('type');
            $uri = $this->input->post('uri') == '/' ? '/' : trim($this->input->post('uri'), '/');
            $parent_id = $this->input->post('parent_id');
            $title = $this->input->post('title');
            $template = $this->input->post('template');
            // page list item url
            $diagram->type = $type;
            $diagram->uri = $uri;
            $diagram->parent_id = $parent_id;
            $diagram->title = $title;
            $diagram->template = $template;
            $diagram->content = $this->input->post('content');
            $diagram->metavalue = '';

            if (empty($diagram->id)) {
                $diagram->date = time();
                $diagram->user_id = $this->user->id;
            }

            $list = $this->input->post('list');
            $list = self::_customfiled_to_object($list); // change a array to an customfield object
            if ($diagram->validate($post) and $diagram->is_unique_uri($uri, $type)) {
                $diagram->save();
                $diagram->order = $diagram->id; // set the diagram display order
                ORM::factory('customfield')->where('diagram_id', $diagram->id)->delete_all();
                foreach($list as $customfield) {
                    if (!empty($customfield->title) and !empty($customfield->key)) {
                        $customfield->diagram_id = $diagram->id;
                        $customfield->save();
                    }
                }
                // save diagram
                $diagram->save();
                // update the uris cache
                Diagram::cache_uris();
                if ($action == 'edit') {
                    $tip = 'Edit done.';
                    $redirect = 'diagram_manage';
                } else {
                    // redirect to the tip add done
                    $tip = 'Add done.';
                    $redirect = "diagram_manage/diagram_new/$diagram->id/add_done/";
                }
                Tip::set(T::_($tip) . ' ' . html::admin_anchor("/diagram_manage/diagram_new/$diagram->id/edit?redirect_uri=diagram_manage/diagram_new", T::_('View or edit')));
                $redirect_uri = $this->input->get('redirect_uri');
                if (!empty($redirect_uri)) {
                    $redirect = $redirect_uri;
                }
                url::admin_redirect($redirect);
            } else {
                Tip::set('Diagram uri is not unique.');
            }
        }

        // make the view
        $view = new View('layouts/admin');
        // type checked status
        $view->type_page = '';
        $view->type_list = '';
        $view->type_item = '';
        $view->type_url = '';

        $view->title = '';
        $view->uri = '';

        // page content;
        $view->id = $diagram->id;
        $view->{"type_$diagram->type"} = True;
        $view->title = $diagram->title;
        $view->content = $diagram->content;
        $view->uri = $diagram->uri;
        $view->template = $diagram->template;

        // set the diagram type check status
        if ($action == 'edit') {
            $view->buttom = 'Edit';
            $view->page_title = 'Diagram Edit';
            $parent_id = $diagram->parent_id;
        } else {
            $view->buttom = 'Add new';
            $view->page_title = 'Diagram New';
        }

        $view->customfields = $list;

        $view->select_options = Diagram::get_diagram_select(array('uses'=>'diagram', 'selected'=>$parent_id, 'current_diagram_id'=>$diagram->id));
        $view->templates = Template::all_as_array(Kohana::config('config.theme'));
        $view->field_types = CustomField::types();
        
        $view->render(TRUE);
    }

     /*
     * delete diagram and custom fields by diagram id
     * @param integer diagram id
     */
    public function delete($id) {
        $diagram = new Diagram_Model($id);
        if (!empty($diagram->id)) {
            $diagrams = Diagram::cache_diagram_children($diagram->id);
            $diagrams[] = $diagram->id;

            // customfilds的删除需要改进, 用foeach循环删除不是一个好办法
            foreach($diagrams as $child) {
                // delete custom fields
                ORM::factory('customfield')->where('diagram_id', $child)->delete_all();

                // delete posts
                $posts = ORM::factory('post')->where('diagram_id', $child)->find_all();
                foreach($posts as $post) {
                    // delete attachments
                    foreach($post->attachments as $attach) {
                        unlink(DOCROOT . $attach->filename);
                    }
                    ORM::factory('attachment')->where('post_id', $post->id)->delete_all();

                    // delete custom values
                    ORM::factory('customvalue')->where('post_id', $post->id)->delete_all();
                }
                // delete all posts
                ORM::factory('post')->where('diagram_id', $child)->delete_all();
            }
            // delete diagrams
            ORM::factory('diagram')->delete_all($diagrams);
            // update the uris cache
            Diagram::cache_uris();
        }
        url::admin_redirect("/diagram_manage/index/delete_done");
    }

    /*
     * move up diagram order
     * @param string up/down
     * @param integer diagram id
      */
    public function move($action, $id) {
        Diagram::move($action, $id);
        url::admin_redirect("/diagram_manage/index/$id/move_done/#diagram_$id");
    }

    /* ajax check is unique diagram uri
    */
    public function is_unique_uri($id, $type) {
        $diagram = new Diagram_Model($id);
        $uri = $this->input->get('uri');
        if ($diagram->is_unique_uri($uri, $type)) {
            echo 'true';
        } else {
            echo 'false';
        }
    }

    protected function _customfiled_to_object($list = array()) {
        $results = array();
        // save list custom fields
        if (!empty($list['fields']['title']) && !empty($list['fields']['key']) && is_array($list['fields']['title']) && is_array($list['fields']['key'])) {
            foreach($list['fields']['title'] as $key => $value) {
                $customfield = new Customfield_Model();
                $customfield->type = $list['fields']['type'][$key];
                $customfield->metavalue = $list['fields']['metavalue'][$key];
                $customfield->title = $value;
                $customfield->key = $list['fields']['key'][$key];
                $customfield->order = empty($list['fields']['order'][$key]) ? 0 : $list['fields']['order'][$key];
                $results[$key] = $customfield;
            }
        }
        return $results;
    }
}
